@@ -9,7 +9,7 @@
 #
 package Config::Model::Tester;
 {
-  $Config::Model::Tester::VERSION = '2.044';
+  $Config::Model::Tester::VERSION = '2.045';
 }
 
 use warnings;
@@ -58,6 +58,7 @@ sub setup_test {
     $wr_root->mkpath( { mode => 0755 } );
 
     my $wr_dir    = $wr_root->subdir('test-' . $t_name);
+    my $wr_dir2   = $wr_root->subdir('test-' . $t_name.'-w');
     my $conf_file ;
     $conf_file = $wr_dir->file($conf_dir,$conf_file_name) if defined $conf_file_name;
 
@@ -96,7 +97,7 @@ sub setup_test {
     }
     ok( 1, "Copied $model_test example $t_name" );
 
-    return ( $wr_dir, $conf_file, $ex_data, @file_list );
+    return ( $wr_dir, $wr_dir2, $conf_file, $ex_data, @file_list );
 }
 
 #
@@ -106,14 +107,17 @@ sub list_test_files {
     my $debian_dir = shift;
     my @file_list ;
 
-    find(
-        {
-            wanted => sub { push @file_list, $_ unless -d; },
-            no_chdir => 1
-        },
-        $debian_dir->stringify
-    );
-    map { s!^$debian_dir!!; } @file_list;
+	my $chop = scalar $debian_dir->dir_list();
+	my $scan = sub {
+		my ($child) = @_;
+		return if $child->is_dir ;
+		my @l = $child->components();
+		splice @l,0,$chop;
+		push @file_list, '/'.join('/',@l) ; # build a unix-like path even on windows
+	};
+
+	$debian_dir->recurse(callback => $scan);
+
     return sort @file_list;
 }
 
@@ -154,7 +158,7 @@ sub run_model_test {
         } 
         note("Beginning subtest $model_test $t_name");
 
-        my ($wr_dir, $conf_file, $ex_data, @file_list) 
+        my ($wr_dir, $wr_dir2, $conf_file, $ex_data, @file_list) 
             = setup_test ($model_test, $t_name, $wr_root,$t->{setup});
             
         if ($t->{config_file}) {
@@ -303,13 +307,12 @@ sub run_model_test {
         }
 
         # create another instance to read the conf file that was just written
-        my $wr_dir2 = $wr_dir->stringify .'-w' ;
-        dircopy( $wr_dir, $wr_dir2 )
+        dircopy( $wr_dir->stringify, $wr_dir2->stringify )
           or die "can't copy from $wr_dir to $wr_dir2: $!";
 
         my $i2_test = $model->instance(
             root_class_name => $model_to_test,
-            root_dir        => $wr_dir2,
+            root_dir        => $wr_dir2->stringify,
             config_file     => $t->{config_file} ,
             instance_name   => "$model_test-$t_name-w",
         );
